>From 7d2a99eff13c3bb5a1e365c0301a68421d79b2f9 Mon Sep 17 00:00:00 2001
From: Mike Miller <mtmiller@debian.org>
Date: Fri, 28 Aug 2015 23:31:03 -0400
Subject: [PATCH] debian-distro-info: Support oldstable with --alias.

Closes: #784284
---
 distro-info-util.c       | 11 ++++++++---
 doc/debian-distro-info.1 |  6 +++---
 2 files changed, 11 insertions(+), 6 deletions(-)

diff --git a/distro-info-util.c b/distro-info-util.c
index 48b5a5d..0c94ff1 100644
--- a/distro-info-util.c
+++ b/distro-info-util.c
@@ -520,8 +520,8 @@ static void print_help(void) {
 
     printf(""
 #ifdef DEBIAN
-           "      --alias=DIST       print the alias (stable, testing, unstable) relative to\n"
-           "                         the distribution codename passed as an argument\n"
+           "      --alias=DIST       print the alias (oldstable, stable, testing, unstable)\n"
+           "                         relative to the given distribution codename\n"
 #endif
            "  -a  --all              list all known versions\n"
            "  -d  --devel            latest development version\n"
@@ -848,15 +848,20 @@ int main(int argc, char *argv[]) {
 
 #ifdef DEBIAN
     if(alias_codename) {
+        const distro_t *oldstable = get_distro(distro_list, date, filter_oldstable,
+                                               select_oldstable);
         const distro_t *stable = get_distro(distro_list, date, filter_stable,
                                             select_latest_release);
         const distro_t *testing = get_distro(distro_list, date, filter_testing,
                                              select_latest_created);
         const distro_t *unstable = get_distro(distro_list, date, filter_devel,
                                               select_first);
-        if(unlikely(stable == NULL || testing == NULL || unstable == NULL)) {
+        if(unlikely(oldstable == NULL || stable == NULL || testing == NULL ||
+                    unstable == NULL)) {
             fprintf(stderr, NAME ": " OUTDATED_ERROR "\n");
             return_value = EXIT_FAILURE;
+        } else if(strcmp(oldstable->series, alias_codename) == 0) {
+            printf("oldstable\n");
         } else if(strcmp(stable->series, alias_codename) == 0) {
             printf("stable\n");
         } else if(strcmp(testing->series, alias_codename) == 0) {
diff --git a/doc/debian-distro-info.1 b/doc/debian-distro-info.1
index 10fb940..5222343 100644
--- a/doc/debian-distro-info.1
+++ b/doc/debian-distro-info.1
@@ -27,11 +27,11 @@ date for calculating the version (default: today)
 display help message and exit
 .TP
 \fB\-\-alias\fR=\fIDIST
-print the alias (stable, testing, unstable) relative to
+print the alias (oldstable, stable, testing, unstable) relative to
 the distribution codename passed as an argument.
 Only distribution codenames composed of lower case ASCII letters are accepted,
-and if the distribution does not qualify as stable, testing or unstable, then
-the same codename passed as argument is returned.
+and if the distribution does not qualify as oldstable, stable, testing, or
+unstable, then the same codename passed as argument is returned.
 .TP
 \fB\-a\fR, \fB\-\-all\fR
 list all known versions
-- 
2.5.0

